@@ -1,6 +1,6 @@
 import elegy
-import haiku as hk
-from haiku.testing import transform_and_run
+
+
 import jax.numpy as jnp
 
 
@@ -11,7 +11,7 @@ import jax.numpy as jnp
 # debugpy.wait_for_client()
 
 
-@transform_and_run
+#
 def test_basic():
 
     y_true = jnp.array([[0, 1, 0], [0, 0, 1]])
