@@ -1,26 +1,20 @@
 # Implementation based on Tensorflow Keras:
 # https://github.com/tensorflow/tensorflow/blob/v2.2.0/tensorflow/python/keras/losses.py#L44-L201
 
-from abc import abstractmethod
-import numpy as np
-
-from numpy.lib.arraysetops import isin
-from elegy import types
-from enum import Enum
-import re
 import typing as tp
+from abc import abstractmethod
+from enum import Enum
 
-
-import haiku as hk
 import jax.numpy as jnp
-
-from elegy import utils
+import numpy as np
+from elegy import types, utils
+from numpy.lib.arraysetops import isin
 
 
 class Reduction(Enum):
     """
     Types of loss reduction.
-    
+
     Contains the following values:
     * `NONE`: Weighted losses with one dimension reduced (axis=-1, or axis
         specified by loss function). When this reduction type used with built-in
@@ -71,21 +65,23 @@ class Loss:
     details on this.
     """
 
+    # Methods used for auto docs
+    __all__ = ["__init__", "call"]
+
     def __init__(
         self,
         reduction: tp.Optional[Reduction] = None,
-        name: tp.Optional[str] = None,
         weight: tp.Optional[float] = None,
         on: tp.Optional[types.IndexLike] = None,
+        name: tp.Optional[str] = None,
     ):
         """
         Initializes `Loss` class.
-        
+
         Arguments:
             reduction: (Optional) Type of `elegy.losses.Reduction` to apply to
                 loss. Default value is `SUM_OVER_BATCH_SIZE`. For almost all cases
                 this defaults to `SUM_OVER_BATCH_SIZE`.
-            name: Optional name for the loss.
             weight: Optional weight contribution for the total loss. Defaults to `1`.
             on: A string or integer, or iterable of string or integers, that
                 indicate how to index/filter the `y_true` and `y_pred`
@@ -94,39 +90,35 @@ class Loss:
                 the structures will be indexed iteratively, for example if `on = ["a", 0, "b"]`
                 then `y_true = y_true["a"][0]["b"]`, same for `y_pred`. For more information
                 check out [Keras-like behavior](https://poets-ai.github.io/elegy/guides/modules-losses-metrics/#keras-like-behavior).
+            name: Optional name for the instance, if not provided lower snake_case version
+                of the name of the class is used instead.
         """
-        self.name = (
-            name
-            if name is not None
-            else re.sub(r"(?<!^)(?=[A-Z])", "_", self.__class__.__name__).lower()
-        )
+        self.name = name if name is not None else utils.get_name(self)
         self.weight = weight if weight is not None else 1.0
         self._reduction = (
             reduction if reduction is not None else Reduction.SUM_OVER_BATCH_SIZE
         )
         self._labels_filter = (on,) if isinstance(on, (str, int)) else on
-        self.call = utils.inject_dependencies(self.call)
+        self._signature_f = self.call
 
     def __call__(
         self,
-        y_true=None,
-        y_pred=None,
-        sample_weight: tp.Optional[jnp.ndarray] = None,
+        *args,
         **kwargs,
     ):
 
         if self._labels_filter is not None:
-            if y_true is not None:
+            if "y_true" in kwargs and kwargs["y_true"] is not None:
                 for index in self._labels_filter:
-                    y_true = y_true[index]
+                    kwargs["y_true"] = kwargs["y_true"][index]
 
-            if y_pred is not None:
+            if "y_pred" in kwargs and kwargs["y_pred"] is not None:
                 for index in self._labels_filter:
-                    y_pred = y_pred[index]
+                    kwargs["y_pred"] = kwargs["y_pred"][index]
 
-        values = self.call(
-            y_true=y_true, y_pred=y_pred, sample_weight=sample_weight, **kwargs
-        )
+        values = self.call(*args, **kwargs)
+
+        sample_weight: tp.Optional[jnp.ndarray] = kwargs.get("sample_weight", None)
 
         if isinstance(values, tp.Dict):
             return {
@@ -137,7 +129,7 @@ class Loss:
             return reduce_loss(values, sample_weight, self.weight, self._reduction)
 
     @abstractmethod
-    def call(self, *args, **kwargs):
+    def call(self, *args, **kwargs) -> tp.Any:
         ...
 
 
@@ -153,7 +145,7 @@ def reduce_loss(values, sample_weight, weight, reduction):
     elif reduction == Reduction.SUM:
         loss = jnp.sum(values)
     elif reduction == Reduction.SUM_OVER_BATCH_SIZE:
-        loss = jnp.sum(values) / jnp.prod(values.shape)
+        loss = jnp.sum(values) / jnp.prod(jnp.array(values.shape))
     else:
         raise ValueError(f"Invalid reduction '{reduction}'")
 
