@@ -10,16 +10,16 @@ from elegy.losses.loss import Loss, Reduction
 def mean_absolute_error(y_true: jnp.ndarray, y_pred: jnp.ndarray) -> jnp.ndarray:
     """
     Computes the mean absolute error between labels and predictions.
-    
+
     After computing the absolute distance between the inputs, the mean value over
     the last dimension is returned.
-    
+
     ```python
     loss = mean(abs(y_true - y_pred), axis=-1)
     ```
 
     Usage:
-    
+
     ```python
     rng = jax.random.PRNGKey(42)
 
@@ -32,11 +32,11 @@ def mean_absolute_error(y_true: jnp.ndarray, y_pred: jnp.ndarray) -> jnp.ndarray
 
     assert jnp.array_equal(loss, jnp.mean(jnp.abs(y_true - y_pred), axis=-1))
     ```
-    
+
     Arguments:
         y_true: Ground truth values. shape = `[batch_size, d0, .. dN]`.
         y_pred: The predicted values. shape = `[batch_size, d0, .. dN]`.
-    
+
     Returns:
         Mean absolute error values. shape = `[batch_size, d0, .. dN-1]`.
     """
@@ -82,7 +82,7 @@ class MeanAbsoluteError(Loss):
     model = elegy.Model(
         module_fn,
         loss=elegy.losses.MeanAbsoluteError(),
-        metrics=elegy.metrics.Mean.defer(),
+        metrics=elegy.metrics.Mean(),
     )
     ```
     """
@@ -90,9 +90,9 @@ class MeanAbsoluteError(Loss):
     def __init__(
         self,
         reduction: tp.Optional[Reduction] = None,
-        name: tp.Optional[str] = None,
         weight: tp.Optional[float] = None,
         on: tp.Optional[types.IndexLike] = None,
+        **kwargs
     ):
         """
         Initializes `Mean` class.
@@ -101,7 +101,6 @@ class MeanAbsoluteError(Loss):
             reduction: (Optional) Type of `elegy.losses.Reduction` to apply to
                 loss. Default value is `SUM_OVER_BATCH_SIZE`. For almost all cases
                 this defaults to `SUM_OVER_BATCH_SIZE`.
-            name: Optional name for the loss.
             weight: Optional weight contribution for the total loss. Defaults to `1`.
             on: A string or integer, or iterable of string or integers, that
                 indicate how to index/filter the `y_true` and `y_pred`
@@ -112,7 +111,7 @@ class MeanAbsoluteError(Loss):
                 check out [Keras-like behavior](https://poets-ai.github.io/elegy/guides/modules-losses-metrics/#keras-like-behavior).
         """
 
-        return super().__init__(reduction=reduction, name=name, weight=weight, on=on)
+        return super().__init__(reduction=reduction, weight=weight, on=on, **kwargs)
 
     def call(
         self,
@@ -144,7 +143,7 @@ class MeanAbsoluteError(Loss):
             Weighted loss float `Tensor`. If `reduction` is `NONE`, this has
                 shape `[batch_size, d0, .. dN-1]`; otherwise, it is scalar. (Note `dN-1`
                 because all loss functions reduce by 1 dimension, usually axis=-1.)
-        
+
         Raises:
             ValueError: If the shape of `sample_weight` is invalid.
         """
